/**
 * @author Mike Tung <miketung2013@gmail.com>
 * @license
 * Copyright Mike Tung All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file
 */
import { OnChanges, OnDestroy, OnInit } from '@angular/core';
import * as d3 from 'd3';
import { ChartService } from '../shared/chart.service';
import { DataService } from '../shared/data.service';
import { ToolTipService } from '../shared/tooltip.service';
export declare class HorizontalBarChartComponent implements OnInit, OnChanges, OnDestroy {
    private chartService;
    private dataService;
    private tooltipService;
    /**
     * Obtain the settings for making the chart here and define defaults if none are specified.
     */
    width: number;
    height: number;
    margins: {
        'top': number;
        'right': number;
        'bottom': number;
        'left': number;
    };
    data: {}[];
    x: string;
    y: string;
    chartHeight: number;
    chartWidth: number;
    chart: d3.Selection<any, any, any, any>;
    xScale: d3.ScaleLinear<any, any>;
    yScale: d3.ScaleBand<any>;
    xData: number[];
    yData: string[];
    private tooltipLabels;
    private chartContainer;
    constructor(chartService: ChartService, dataService: DataService, tooltipService: ToolTipService);
    ngOnInit(): void;
    /**
     * This life cycle hook tells angular to detect any changes and to adjust
     * the chart accordingly and also serves to separate out different
     * instances of the same chart
     * */
    ngOnChanges(): void;
    ngOnDestroy(): void;
    /**
     * This makes the axes for the chart.
     *
     * @param {string} axis - the axis type to make
     * @param {object} scale - d3 scale object to scale svg and data
     *
     */
    makeAxis(axis: string, scale: any): void;
    /**
     * This is the main method to render the bar chart it operates on the d3
     * selection supplied and appends the scales, bars to the selection.
     *
     * @param {array} dataSet - objects to draw data with
     */
    private draw(dataSet);
}
