/**
 * @author Mike Tung <miketung2013@gmail.com>
 * @license
 * Copyright Mike Tung All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file
 */
import { ElementRef, OnChanges, OnDestroy, OnInit } from '@angular/core';
import * as d3 from 'd3';
import { ChartService } from '../shared/chart.service';
import { ScatterplotOptions } from './ScatterPlotOptions';
import { DataService } from '../shared/data.service';
import { ToolTipService } from '../shared/tooltip.service';
export declare class ScatterPlotComponent implements OnInit, OnChanges, OnDestroy {
    private chartService;
    private dataService;
    private tooltipService;
    /**
     * Setup the chart properties and define defaults if none are specified
     */
    width: number;
    height: number;
    margins: {
        'top': number;
        'right': number;
        'bottom': number;
        'left': number;
    };
    data: {}[];
    x: string;
    y: string;
    dotSize: number;
    dataPointShape: ScatterplotOptions;
    chartHeight: number;
    chartWidth: number;
    chart: d3.Selection<any, any, any, any>;
    xScale: d3.ScaleLinear<number, any>;
    yScale: d3.ScaleLinear<number, any>;
    xData: number[];
    yData: number[];
    private tooltipLabels;
    chartContainer: ElementRef;
    constructor(chartService: ChartService, dataService: DataService, tooltipService: ToolTipService);
    ngOnInit(): void;
    /**
     * This life cycle hook tells angular to detect any changes and to adjust
     * the chart accordingly and also serves to separate out different
     * instances of the same chart
     * */
    ngOnChanges(): void;
    ngOnDestroy(): void;
    /**
     * Main function to draw the scatter plot, it requires a dataset in order to draw
     * on the reference element supplied from view child
     *
     * @param{Array<object>} dataSet - data objects in an array.
     */
    private draw(dataSet);
    /**
     * This makes the axes for the chart.
     *
     * @param {string} axis - the axis type to make
     * @param {object} scale - d3 scale object to scale svg and data
     *
     */
    makeAxis(axis: string, scale: any): void;
}
