/**
 * @author Mike Tung <miketung2013@gmail.com>
 * @license
 * Copyright Mike Tung All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file
 */
import { ElementRef } from '@angular/core';
import * as d3 from 'd3';
import { Tooltip } from './models/tooltip';
export declare class ToolTipService {
    /**
     * A method to add tooltips to a d3 selection object, tooltip will show x, y datapoints and
     * any meta data mentioned in message property
     *
     * @param {d3.Selection<any, any, any, any>} selection - d3 selection with data being drawn on
     * @param {Tooltip} labelKeys -Tooltip model telling the service what keys to use to extract datum
     * @param {ElementRef} refElement - Reference to the component DOM template that svg is working on
     *
     * @return {d3.Selection<any, any, any, any>} d3 selection with tooltip applied
     */
    addTooltip(selection: d3.Selection<any, any, any, any>, labelKeys: Tooltip, refElement: ElementRef): d3.Selection<any, any, any, any>;
}
